from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsHurricaneHarborOaxtepec(SixFlagsPark):
    def __init__(self):
        super(SixFlagsHurricaneHarborOaxtepec, self).__init__()

    def getId(self):
        return 32
    def getCity(self):
        return 'Oaxtepec'
    def getName(self):
        return 'Six Flags Hurricane Harbor, Oaxtepec'

    